package com.game.business.websocket.client;

import com.alibaba.fastjson2.JSONObject;
import com.game.business.config.GameOneConfig;
import com.game.business.domain.AppGame;
import com.game.business.domain.AppGameLottery;
import com.game.business.service.IAppGameLotteryService;
import com.game.business.service.IAppGameService;
import com.game.business.util.Common;
import com.game.common.utils.DateUtils;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import javax.websocket.*;

@Component
@ClientEndpoint
public class GameOneClient {

    @Autowired
    private IAppGameLotteryService appGameLotteryService;

    @Autowired
    private IAppGameService appGameService;

    @OnOpen
    public void onOpen(Session session) throws Exception{
        System.out.printf("game one 游戏已连接 server");
        // 发送游戏编码
        session.getBasicRemote().sendText("{\"code\":\"" + Common.GAME_ONE_CODE + "\"}");
    }

    @OnClose
    public void onClose(Session session) throws Exception{
        System.out.printf("game on 游戏已断开 server");
        connect();
    }

    @OnError
    public void onError(Session session, Throwable throwable) throws Exception{
        System.out.printf("game one 连接异常 [" + throwable.getMessage() + "]");
        connect();
    }

    public void connect(){
        synchronized (this){
            try {
                GameOneConfig.webSocketConnent.connect();
            }catch (Exception e){
                System.out.printf("连接 game on [socket] 异常" + e.getMessage());
            }
        }
    }

    @OnMessage
    public void onMessage(Session session, String message){
        try {
            if(StringUtils.isBlank(message)){
                System.out.printf("game one 数据为空");
                return;
            }

            System.out.printf("game one 接收数据[" + message + "]");

            JSONObject jsonObject = JSONObject.parseObject(message);
            String code = jsonObject.getString("code");

            if(StringUtils.isBlank(code) || !code.equals(Common.GAME_ONE_CODE)){
                System.out.printf("game one 接收数据错误[" + message + "]");
                return;
            }

            // 是否为开奖
            Integer isLottery = jsonObject.getInteger("isLottery");
            if(isLottery == 0){
                return;
            }

            AppGame appGame = appGameService.selectAppGameById(0L);

            String gameDate = jsonObject.getString("gameDate");
            String gameRecordDate = jsonObject.getString("gameRecordDate");
            String gameLotterySucc = jsonObject.getString("gameLotterySucc");

            AppGameLottery appGameLottery = new AppGameLottery();
            appGameLottery.setGameId(appGame.getId());
            appGameLottery.setGameDate(gameDate);
            appGameLottery.setIsLottery(isLottery);
            appGameLottery.setGameRecordDate(DateUtils.parseDate(gameRecordDate));
            appGameLottery.setGameLotterySucc(gameLotterySucc);

            appGameLotteryService.save(appGameLottery);

            // 开奖结算

        }catch (Exception e){
            e.printStackTrace();
            System.out.printf("game one 接收数据异常[" + e.getMessage() + "]");
        }
    }
}
